@@ -1,4 +1,4 @@
-# Copyright 2013-2021 Reahl Software Services (Pty) Ltd. All rights reserved.
+# Copyright 2013-2022 Reahl Software Services (Pty) Ltd. All rights reserved.
 #
 #    This file is part of Reahl.
 #
@@ -26,7 +26,7 @@ import sys
 import traceback
 import socket
 import ssl
-from contextlib import contextmanager
+import contextlib
 import logging
 import functools
 import pkg_resources
@@ -437,7 +437,7 @@ class ReahlWebServer:
         self.port = int(config.web.default_http_port)
         self.encrypted_port = int(config.web.encrypted_http_port)
         certfile = pkg_resources.resource_filename(__name__, 'reahl_development_cert.pem')
-        self.reahl_wsgi_app = WrappedApp(ReahlWSGIApplication(config))
+        self.reahl_wsgi_app = WrappedApp(ReahlWSGIApplication(config, start_on_first_request=True))
         try:
             self.httpd = ReahlWSGIServer.make_server('', self.port, self.reahl_wsgi_app)
             self.httpsd = SSLCapableWSGIServer.make_server('', self.encrypted_port, certfile, self.reahl_wsgi_app)
@@ -448,24 +448,25 @@ class ReahlWebServer:
             raise AssertionError(message)
 
     def main_loop(self, context=None):
-        if context:
-            context.install()
-        while self.running:
-            try:
-                self.httpd.serve_async(in_separate_thread=self.in_separate_thread)
-                self.httpsd.serve_async(in_separate_thread=self.in_separate_thread)
-            except:  
-                # When running as a stand-alone server, we keep the server running, but else break so tests break
-                if self.in_separate_thread and self.running:
-                    print(traceback.format_exc(), file=sys.stderr)
-                else:
-                    raise
+
+        context = context or contextlib.nullcontext()
+        with context:
+            while self.running:
+                try:
+                    self.httpd.serve_async(in_separate_thread=self.in_separate_thread)
+                    self.httpsd.serve_async(in_separate_thread=self.in_separate_thread)
+                except:
+                    # When running as a stand-alone server, we keep the server running, but else break so tests break
+                    if self.in_separate_thread and self.running:
+                        print(traceback.format_exc(), file=sys.stderr)
+                    else:
+                        raise
 
     def start_thread(self):
         assert not self.running
         self.running = True
         try:
-            context = ExecutionContext.get_context()
+            context = ExecutionContext.get_context().copy()
         except NoContextFound:
             context = None
         self.httpd_thread = Thread(target=functools.partial(self.main_loop, context))
@@ -486,13 +487,14 @@ class ReahlWebServer:
         finally:
             self.stop()
 
-    def start(self, in_separate_thread=True,  connect=False):
+    def start(self, in_separate_thread=True):
         """Starts the webserver and web application.
         
            :keyword in_separate_thread: If False, the server handles requests in the same thread as your tests.
-           :keyword connect: If True, also connects to the database.
+
+           .. versionchanged:: 6.1 
+              Removed connect= kwarg - the ReahlWSGIApplication is now responsible for connecting when it is started which it will do if it detects that is not connected
         """
-        self.reahl_wsgi_app.start(connect=connect)
         self.in_separate_thread = in_separate_thread
 
         if self.in_separate_thread:
@@ -536,7 +538,7 @@ class ReahlWebServer:
         for handler in self.handlers.values():
             handler.reinstall()
 
-    @contextmanager
+    @contextlib.contextmanager
     def paused(self, wait_till_done_serving=True):
         self.restore_handlers()
         try:
@@ -548,7 +550,7 @@ class ReahlWebServer:
             finally:
                 self.reinstall_handlers()
 
-    @contextmanager
+    @contextlib.contextmanager
     def in_background(self, wait_till_done_serving=True):
         """Returns a context manager. Within the context of this context manager, the webserver is temporarily run
            in a separate thread. After the context managed by this context manager is exited, the server reverts to 
